package com.ruoyi.project.plant.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.plant.mapper.TBrithstaffmgrMapper;
import com.ruoyi.project.plant.domain.TBrithstaffmgr;
import com.ruoyi.project.plant.service.ITBrithstaffmgrService;

import javax.annotation.Resource;

/**
 * 生日提醒Service业务层处理
 *
 * @author ruoyi
 * @date 2021-01-18
 */
@Service
public class TBrithstaffmgrServiceImpl implements ITBrithstaffmgrService
{
    @Resource
    private TBrithstaffmgrMapper tBrithstaffmgrMapper;

    /**
     * 查询生日提醒
     *
     * @param id 生日提醒ID
     * @return 生日提醒
     */
    @Override
    public TBrithstaffmgr selectTBrithstaffmgrById(Long id)
    {
        return tBrithstaffmgrMapper.selectTBrithstaffmgrById(id);
    }

    /**
     * 查询生日提醒列表
     *
     * @param tBrithstaffmgr 生日提醒
     * @return 生日提醒
     */
    @Override
    public List<TBrithstaffmgr> selectTBrithstaffmgrList(TBrithstaffmgr tBrithstaffmgr)
    {
        return tBrithstaffmgrMapper.selectTBrithstaffmgrList(tBrithstaffmgr);
    }

    /**
     * 新增生日提醒
     *
     * @param tBrithstaffmgr 生日提醒
     * @return 结果
     */
    @Override
    public int insertTBrithstaffmgr(TBrithstaffmgr tBrithstaffmgr)
    {
        return tBrithstaffmgrMapper.insertTBrithstaffmgr(tBrithstaffmgr);
    }

    /**
     * 修改生日提醒
     *
     * @param tBrithstaffmgr 生日提醒
     * @return 结果
     */
    @Override
    public int updateTBrithstaffmgr(TBrithstaffmgr tBrithstaffmgr)
    {
        return tBrithstaffmgrMapper.updateTBrithstaffmgr(tBrithstaffmgr);
    }

    /**
     * 批量删除生日提醒
     *
     * @param ids 需要删除的生日提醒ID
     * @return 结果
     */
    @Override
    public int deleteTBrithstaffmgrByIds(Long[] ids)
    {
        return tBrithstaffmgrMapper.deleteTBrithstaffmgrByIds(ids);
    }

    /**
     * 删除生日提醒信息
     *
     * @param id 生日提醒ID
     * @return 结果
     */
    @Override
    public int deleteTBrithstaffmgrById(Long id)
    {
        return tBrithstaffmgrMapper.deleteTBrithstaffmgrById(id);
    }

    @Override
    public int deleteAllBirthstaffmgr() {
        return tBrithstaffmgrMapper.deleteAllBirthstaffmgr();
    }
}
